@@ -22,7 +22,6 @@ describe 'glance::api' do
       :location_strategy              => '<SERVICE DEFAULT>',
       :purge_config                   => false,
       :delayed_delete                 => '<SERVICE DEFAULT>',
-      :scrub_time                     => '<SERVICE DEFAULT>',
       :enforce_secure_rbac            => '<SERVICE DEFAULT>',
       :use_keystone_limits            => '<SERVICE DEFAULT>',
       :image_cache_dir                => '/var/lib/glance/image-cache',
@@ -71,7 +70,6 @@ describe 'glance::api' do
         :filesystem_store_file_perm     => '0644',
         :location_strategy              => 'store_type',
         :delayed_delete                 => 'true',
-        :scrub_time                     => '10',
         :enforce_secure_rbac            => 'true',
         :use_keystone_limits            => 'true',
         :image_cache_dir                => '/tmp/glance',
@@ -137,7 +135,6 @@ describe 'glance::api' do
             'show_multiple_locations',
             'location_strategy',
             'delayed_delete',
-            'scrub_time',
             'enforce_secure_rbac',
             'use_keystone_limits',
             'image_cache_dir',
